@@ -40,6 +40,7 @@ const char* attr_name(AttrTag t)
 		"&deprecated",
 		"&is_assigned",
 		"&is_used",
+		"&ordered",
 	};
 
 	return attr_names[int(t)];
@@ -242,8 +243,9 @@ void Attributes::AddAttr(AttrPtr attr, bool is_redef)
 	// We only check the attribute after we've added it, to facilitate
 	// generating error messages via Attributes::Describe.  If the
 	// instantiator of the object specified a null type, however, then
-	// that's a signal to skip the checking.
-	if ( type )
+	// that's a signal to skip the checking. If the type is error,
+	// there's no point checking attributes either.
+	if ( type && ! IsErrorType(type->Tag()) )
 		CheckAttr(attr.get());
 
 	// For ADD_FUNC or DEL_FUNC, add in an implicit REDEF, since
@@ -387,10 +389,10 @@ void Attributes::CheckAttr(Attr* a)
 
 			int num_expires = 0;
 
-			for ( const auto& a : attrs )
+			for ( const auto& at : attrs )
 				{
-				if ( a->Tag() == ATTR_EXPIRE_READ || a->Tag() == ATTR_EXPIRE_WRITE ||
-				     a->Tag() == ATTR_EXPIRE_CREATE )
+				if ( at->Tag() == ATTR_EXPIRE_READ || at->Tag() == ATTR_EXPIRE_WRITE ||
+				     at->Tag() == ATTR_EXPIRE_CREATE )
 					num_expires++;
 				}
 
@@ -513,7 +515,7 @@ void Attributes::CheckAttr(Attr* a)
 				}
 
 			// Only support atomic types for the moment, unless
-			// explicitly overriden
+			// explicitly overridden
 			if ( ! type->AsTableType()->IsSet() &&
 			     ! input::Manager::IsCompatibleType(type->AsTableType()->Yield().get(), true) &&
 			     ! Find(ATTR_BROKER_STORE_ALLOW_COMPLEX) )
@@ -548,7 +550,7 @@ void Attributes::CheckAttr(Attr* a)
 				}
 
 			// Only support atomic types for the moment, unless
-			// explicitly overriden
+			// explicitly overridden
 			if ( ! type->AsTableType()->IsSet() &&
 			     ! input::Manager::IsCompatibleType(type->AsTableType()->Yield().get(), true) &&
 			     ! Find(ATTR_BROKER_STORE_ALLOW_COMPLEX) )
@@ -624,6 +626,11 @@ void Attributes::CheckAttr(Attr* a)
 			break;
 			}
 
+		case ATTR_ORDERED:
+			if ( type->Tag() != TYPE_TABLE )
+				Error("&ordered only applicable to tables");
+			break;
+
 		default:
 			BadTag("Attributes::CheckAttr", attr_name(a->Tag()));
 		}
