@@ -120,6 +120,17 @@ Frame* Frame::Clone() const
 	return other;
 	}
 
+Frame* Frame::CloneForTrigger() const
+	{
+	Frame* other = new Frame(0, function, func_args);
+
+	other->call = call;
+	other->assoc = assoc;
+	other->trigger = trigger;
+
+	return other;
+	}
+
 static bool val_is_func(const ValPtr& v, ScriptFunc* func)
 	{
 	if ( v->GetType()->Tag() != TYPE_FUNC )
@@ -206,7 +217,9 @@ std::pair<bool, FramePtr> Frame::Unserialize(const broker::vector& data,
 
 const detail::Location* Frame::GetCallLocation() const
 	{
-	return call ? call->GetLocationInfo() : call_loc;
+	// This is currently trivial, but we keep it as an explicit
+	// method because it can provide flexibility for compiled code.
+	return call->GetLocationInfo();
 	}
 
 void Frame::SetTrigger(trigger::TriggerPtr arg_trigger)
