@@ -22,7 +22,7 @@ Scope::Scope(IDPtr id, std::unique_ptr<std::vector<AttrPtr>> al)
 	{
 	return_type = nullptr;
 
-	if ( id )
+	if ( scope_id )
 		{
 		const auto& id_type = scope_id->GetType();
 
@@ -31,7 +31,7 @@ Scope::Scope(IDPtr id, std::unique_ptr<std::vector<AttrPtr>> al)
 		else if ( id_type->Tag() != TYPE_FUNC )
 			reporter->InternalError("bad scope id");
 
-		FuncType* ft = id->GetType()->AsFuncType();
+		FuncType* ft = scope_id->GetType()->AsFuncType();
 		return_type = ft->Yield();
 		}
 	}
@@ -190,20 +190,6 @@ ScopePtr pop_scope()
 	return old_top;
 	}
 
-void merge_top_scope()
-	{
-	if ( scopes.size() < 2 )
-		reporter->InternalError("scope merge underflow");
-
-	auto t = pop_scope();
-
-	for ( const auto& v : t->OrderedVars() )
-		{
-		v->SetOffset(top_scope->Length());
-		top_scope->Insert(v->Name(), v);
-		}
-	}
-
 ScopePtr current_scope()
 	{
 	return top_scope;
