@@ -18,12 +18,12 @@ Extract::Extract(RecordValPtr args, file_analysis::File* file, const std::string
 	  filename(arg_filename), limit(arg_limit), depth(0)
 	{
 	char buf[128];
-	file_stream = fopen(filename.data(), "w");
+	file_stream = fopen(filename.data(), "wb");
 
 	if ( file_stream )
 		{
 		// Try to ensure full buffering.
-		if ( setvbuf(file_stream, nullptr, _IOFBF, BUFSIZ) )
+		if ( util::detail::setvbuf(file_stream, nullptr, _IOFBF, BUFSIZ) )
 			{
 			util::zeek_strerror_r(errno, buf, sizeof(buf));
 			reporter->Warning("cannot set buffering mode for %s: %s", filename.data(), buf);
