@@ -65,6 +65,9 @@
 #include "zeek/plugin/Manager.h"
 #include "zeek/script_opt/ScriptOpt.h"
 #include "zeek/session/Manager.h"
+#ifdef HAVE_SPICY
+#include "zeek/spicy/manager.h"
+#endif
 #include "zeek/supervisor/Supervisor.h"
 #include "zeek/telemetry/Manager.h"
 #include "zeek/threading/Manager.h"
@@ -191,6 +194,9 @@ zeek::Broker::Manager* zeek::broker_mgr = nullptr;
 zeek::telemetry::Manager* zeek::telemetry_mgr = nullptr;
 zeek::Supervisor* zeek::supervisor_mgr = nullptr;
 zeek::detail::trigger::Manager* zeek::detail::trigger_mgr = nullptr;
+#ifdef HAVE_SPICY
+zeek::spicy::Manager* zeek::spicy_mgr = nullptr;
+#endif
 
 std::vector<std::string> zeek::detail::zeek_script_prefixes;
 zeek::detail::Stmt* zeek::detail::stmts = nullptr;
@@ -202,11 +208,8 @@ std::shared_ptr<zeek::detail::SampleLogger> zeek::detail::sample_logger;
 zeek::detail::FragmentManager* zeek::detail::fragment_mgr = nullptr;
 
 int signal_val = 0;
-#ifdef _MSC_VER
-char version[] = VERSION;
-#else
-extern char version[];
-#endif
+extern "C" char version[];
+extern "C" const char zeek_build_info[];
 
 const char* zeek::detail::command_line_policy = nullptr;
 vector<string> zeek::detail::params;
@@ -440,6 +443,9 @@ static void terminate_zeek()
 	delete session_mgr;
 	delete fragment_mgr;
 	delete telemetry_mgr;
+#ifdef HAVE_SPICY
+	delete spicy_mgr;
+#endif
 
 	// free the global scope
 	pop_scope();
@@ -535,6 +541,12 @@ SetupResult setup(int argc, char** argv, Options* zopts)
 		exit(0);
 		}
 
+	if ( options.print_build_info )
+		{
+		fprintf(stdout, "%s", zeek_build_info);
+		exit(0);
+		}
+
 	if ( options.run_unit_tests )
 		options.deterministic_mode = true;
 
@@ -626,15 +638,22 @@ SetupResult setup(int argc, char** argv, Options* zopts)
 		supervisor_mgr = new Supervisor(std::move(cfg), std::move(*stem));
 		}
 
+	std::string seed_string;
+	if ( const auto* seed_env = getenv("ZEEK_SEED_VALUES") )
+		seed_string = seed_env;
+
 	const char* seed_load_file = getenv("ZEEK_SEED_FILE");
 
 	if ( options.random_seed_input_file )
 		seed_load_file = options.random_seed_input_file->data();
 
+	if ( seed_load_file && *seed_load_file && ! seed_string.empty() )
+		reporter->FatalError("can't use ZEEK_SEED_VALUES together with ZEEK_SEED_FILE or -G");
+
 	util::detail::init_random_seed(
 		(seed_load_file && *seed_load_file ? seed_load_file : nullptr),
 		options.random_seed_output_file ? options.random_seed_output_file->data() : nullptr,
-		options.deterministic_mode);
+		options.deterministic_mode, seed_string);
 	// DEBUG_MSG("HMAC key: %s\n", md5_digest_print(shared_hmac_md5_key));
 	init_hash_function();
 
@@ -698,6 +717,7 @@ SetupResult setup(int argc, char** argv, Options* zopts)
 	// policy, but we can't parse policy without DNS resolution.
 	dns_mgr->SetDir(".state");
 
+	telemetry_mgr = new telemetry::Manager;
 	iosource_mgr = new iosource::Manager();
 	event_registry = new EventRegistry();
 	packet_mgr = new packet_analysis::Manager();
@@ -707,8 +727,10 @@ SetupResult setup(int argc, char** argv, Options* zopts)
 	file_mgr = new file_analysis::Manager();
 	auto broker_real_time = ! options.pcap_file && ! options.deterministic_mode;
 	broker_mgr = new Broker::Manager(broker_real_time);
-	telemetry_mgr = new telemetry::Manager;
 	trigger_mgr = new trigger::Manager();
+#ifdef HAVE_SPICY
+	spicy_mgr = new spicy::Manager(); // registers as plugin with the plugin manager
+#endif
 
 	plugin_mgr->InitPreScript();
 	file_mgr->InitPreScript();
@@ -833,12 +855,12 @@ SetupResult setup(int argc, char** argv, Options* zopts)
 		if ( reporter->Errors() > 0 )
 			exit(1);
 
+		telemetry_mgr->InitPostScript();
 		iosource_mgr->InitPostScript();
 		log_mgr->InitPostScript();
 		plugin_mgr->InitPostScript();
 		zeekygen_mgr->InitPostScript();
 		broker_mgr->InitPostScript();
-		telemetry_mgr->InitPostScript();
 		timer_mgr->InitPostScript();
 		event_mgr.InitPostScript();
 
@@ -1007,6 +1029,17 @@ SetupResult setup(int argc, char** argv, Options* zopts)
 			exit(0);
 			}
 
+		if ( options.ignore_checksums )
+			{
+			const auto& id = global_scope()->Find("ignore_checksums");
+
+			if ( ! id )
+				reporter->InternalError("global ignore_checksums not defined");
+
+			id->SetVal(zeek::val_mgr->True());
+			ignore_checksums = 1;
+			}
+
 		// Print the ID.
 		if ( options.identifier_to_print )
 			{
@@ -1034,7 +1067,8 @@ SetupResult setup(int argc, char** argv, Options* zopts)
 				segment_logger = profiling_logger;
 			}
 
-		if ( ! run_state::reading_live && ! run_state::reading_traces )
+		if ( ! run_state::reading_live && ! run_state::reading_traces &&
+		     id::find_const("allow_network_time_forward")->AsBool() )
 			// Set up network_time to track real-time, since
 			// we don't have any other source for it.
 			run_state::detail::update_network_time(util::current_time());
@@ -1078,9 +1112,6 @@ SetupResult setup(int argc, char** argv, Options* zopts)
 			g_frame_stack.pop_back();
 			}
 
-		if ( options.ignore_checksums )
-			ignore_checksums = 1;
-
 		if ( zeek_script_loaded )
 			{
 			// Queue events reporting loaded scripts.
